Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MetadataReceiver ¶
type Parameter ¶
type Parameter struct {
Metadata *types.Metadata
Type azure.Value `json:"type"`
DefaultValue azure.Value `json:"defaultValue"`
MaxLength azure.Value `json:"maxLength"`
MinLength azure.Value `json:"minLength"`
}
func (*Parameter) SetMetadata ¶
type Resource ¶
type Resource struct {
Metadata *types.Metadata `json:"-"`
// contains filtered or unexported fields
}
func (*Resource) SetMetadata ¶
type Resources ¶
type Resources []Resource
Resources is a collection of Resource items that can be represented in ARM templates either as an array or as an object (e.g., language v2). This custom unmarshaler normalizes both forms into a flat slice.
type Template ¶
type Template struct {
Metadata *types.Metadata `json:"-"`
Schema azure.Value `json:"$schema"`
ContentVersion azure.Value `json:"contentVersion"`
APIProfile azure.Value `json:"apiProfile"`
Parameters map[string]Parameter `json:"parameters"`
Variables map[string]azure.Value `json:"variables"`
Functions []Function `json:"functions"`
Resources Resources `json:"resources"`
Outputs map[string]azure.Value `json:"outputs"`
}
func (*Template) SetMetadata ¶
Click to show internal directories.
Click to hide internal directories.